.. _dimensionless:

*************************************************************
Dimensionless parameters (`plasmapy.formulary.dimensionless`)
*************************************************************

.. currentmodule:: plasmapy.formulary.dimensionless

.. automodapi:: plasmapy.formulary.dimensionless

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/solar_plasma_beta
